@@ -1,7 +1,8 @@
 /*****************************************************************************
  * Eliot
- * Copyright (C) 2005-2007 Antoine Fraboulet
+ * Copyright (C) 2005-2012 Antoine Fraboulet & Olivier Teulière
  * Authors: Antoine Fraboulet <antoine.fraboulet @@ free.fr>
+ *          Olivier Teulière <ipkiss @@ gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,11 +22,14 @@
 #ifndef DIC_AUTOMATON_H_
 #define DIC_AUTOMATON_H_
 
+#include "logging.h"
+
 class AutomatonHelper;
 struct searchRegExpLists;
 
 class Automaton
 {
+    DEFINE_LOGGER();
 public:
     /// Constructor
     /**
