@@ -18,12 +18,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *****************************************************************************/
 
-#ifndef _GRAMMAR_H_
-#define _GRAMMAR_H_
+#ifndef GRAMMAR_H_
+#define GRAMMAR_H_
 
 class Dictionary;
 class Node;
-class searchRegExpLists;
+struct searchRegExpLists;
 
 bool parseRegexp(const Dictionary &iDic,
                  const wchar_t *input,
