@@ -21,8 +21,6 @@
 
 #include <boost/foreach.hpp>
 
-#include <string>
-#include <cstdio>
 #include <cstdlib> // For rand()
 
 #include <dic.h>
@@ -35,17 +33,17 @@ INIT_LOGGER(game, Bag);
 
 
 Bag::Bag(const Dictionary &iDic)
-    : m_dic(iDic), m_ntiles(0)
+    : m_dic(iDic), m_nbTiles(0)
 {
     BOOST_FOREACH(const Tile &tile, m_dic.getAllTiles())
     {
         m_tilesMap[tile] = tile.maxNumber();
-        m_ntiles += tile.maxNumber();
+        m_nbTiles += tile.maxNumber();
     }
 }
 
 
-unsigned int Bag::in(const Tile &iTile) const
+unsigned Bag::count(const Tile &iTile) const
 {
     map<Tile, int>::const_iterator it = m_tilesMap.find(iTile);
     if (it != m_tilesMap.end())
@@ -54,7 +52,7 @@ unsigned int Bag::in(const Tile &iTile) const
 }
 
 
-unsigned int Bag::getNbVowels() const
+unsigned Bag::getNbVowels() const
 {
     int v = 0;
 
@@ -68,7 +66,7 @@ unsigned int Bag::getNbVowels() const
 }
 
 
-unsigned int Bag::getNbConsonants() const
+unsigned Bag::getNbConsonants() const
 {
     int c = 0;
 
@@ -84,27 +82,27 @@ unsigned int Bag::getNbConsonants() const
 
 void Bag::takeTile(const Tile &iTile)
 {
-    ASSERT(in(iTile),
+    ASSERT(contains(iTile),
            "The bag does not contain the letter " + lfw(iTile.getDisplayStr()));
 
     m_tilesMap[iTile]--;
-    m_ntiles--;
+    m_nbTiles--;
 }
 
 
 void Bag::replaceTile(const Tile &iTile)
 {
-    ASSERT(in(iTile) < iTile.maxNumber(),
+    ASSERT(count(iTile) < iTile.maxNumber(),
            "Cannot replace tile: " + lfw(iTile.getDisplayStr()));
 
     m_tilesMap[iTile]++;
-    m_ntiles++;
+    m_nbTiles++;
 }
 
 
 Tile Bag::selectRandom() const
 {
-    return selectRandomTile(m_ntiles, false, false);
+    return selectRandomTile(m_nbTiles, false, false);
 }
 
 
@@ -120,7 +118,7 @@ Tile Bag::selectRandomConsonant() const
 }
 
 
-Tile Bag::selectRandomTile(unsigned int total,
+Tile Bag::selectRandomTile(unsigned total,
                            bool onlyVowels, bool onlyConsonants) const
 {
     ASSERT(total > 0, "Not enough tiles (of the requested kind) in the bag");
@@ -142,21 +140,11 @@ Tile Bag::selectRandomTile(unsigned int total,
 }
 
 
-void Bag::operator=(const Bag &iOther)
+Bag & Bag::operator=(const Bag &iOther)
 {
     m_tilesMap = iOther.m_tilesMap;
-    m_ntiles = iOther.m_ntiles;
+    m_nbTiles = iOther.m_nbTiles;
+    return *this;
 }
 
 
-void Bag::dumpAll() const
-{
-    std::pair<Tile, int> p;
-    BOOST_FOREACH(p, m_tilesMap)
-    {
-        if (p.second)
-            fprintf(stderr, "%lc[%i] ", p.first.toChar(), p.second);
-    }
-    fprintf(stderr, "\n");
-}
-
