@@ -19,8 +19,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *****************************************************************************/
 
-#include <wctype.h>
-#include <algorithm>
+#include <cwctype>
 #include <cstdio>
 
 #include "dic.h"
@@ -28,69 +27,22 @@
 #include "board.h"
 #include "board_search.h"
 #include "game_params.h"
+#include "board_layout.h"
 #include "tile.h"
 #include "round.h"
 #include "rack.h"
 #include "results.h"
+#include "encoding.h"
 #include "debug.h"
 
-#define oo 0
-#define __ 1
-#define T2 2
-#define T3 3
-#define W2 2
-#define W3 3
+#define BOARD_REALDIM (BOARD_DIM + 2)
 
 
 INIT_LOGGER(game, Board);
 
 
-const int Board::m_tileMultipliers[BOARD_REALDIM][BOARD_REALDIM] =
-{
-    { oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo },
-    { oo,__,__,__,T2,__,__,__,__,__,__,__,T2,__,__,__,oo },
-    { oo,__,__,__,__,__,T3,__,__,__,T3,__,__,__,__,__,oo },
-    { oo,__,__,__,__,__,__,T2,__,T2,__,__,__,__,__,__,oo },
-    { oo,T2,__,__,__,__,__,__,T2,__,__,__,__,__,__,T2,oo },
-    { oo,__,__,__,__,__,__,__,__,__,__,__,__,__,__,__,oo },
-    { oo,__,T3,__,__,__,T3,__,__,__,T3,__,__,__,T3,__,oo },
-    { oo,__,__,T2,__,__,__,T2,__,T2,__,__,__,T2,__,__,oo },
-    { oo,__,__,__,T2,__,__,__,__,__,__,__,T2,__,__,__,oo },
-    { oo,__,__,T2,__,__,__,T2,__,T2,__,__,__,T2,__,__,oo },
-    { oo,__,T3,__,__,__,T3,__,__,__,T3,__,__,__,T3,__,oo },
-    { oo,__,__,__,__,__,__,__,__,__,__,__,__,__,__,__,oo },
-    { oo,T2,__,__,__,__,__,__,T2,__,__,__,__,__,__,T2,oo },
-    { oo,__,__,__,__,__,__,T2,__,T2,__,__,__,__,__,__,oo },
-    { oo,__,__,__,__,__,T3,__,__,__,T3,__,__,__,__,__,oo },
-    { oo,__,__,__,T2,__,__,__,__,__,__,__,T2,__,__,__,oo },
-    { oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo }
-};
-
-
-const int Board::m_wordMultipliers[BOARD_REALDIM][BOARD_REALDIM] =
-{
-    { oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo },
-    { oo,W3,__,__,__,__,__,__,W3,__,__,__,__,__,__,W3,oo },
-    { oo,__,W2,__,__,__,__,__,__,__,__,__,__,__,W2,__,oo },
-    { oo,__,__,W2,__,__,__,__,__,__,__,__,__,W2,__,__,oo },
-    { oo,__,__,__,W2,__,__,__,__,__,__,__,W2,__,__,__,oo },
-    { oo,__,__,__,__,W2,__,__,__,__,__,W2,__,__,__,__,oo },
-    { oo,__,__,__,__,__,__,__,__,__,__,__,__,__,__,__,oo },
-    { oo,__,__,__,__,__,__,__,__,__,__,__,__,__,__,__,oo },
-    { oo,W3,__,__,__,__,__,__,W2,__,__,__,__,__,__,W3,oo },
-    { oo,__,__,__,__,__,__,__,__,__,__,__,__,__,__,__,oo },
-    { oo,__,__,__,__,__,__,__,__,__,__,__,__,__,__,__,oo },
-    { oo,__,__,__,__,W2,__,__,__,__,__,W2,__,__,__,__,oo },
-    { oo,__,__,__,W2,__,__,__,__,__,__,__,W2,__,__,__,oo },
-    { oo,__,__,W2,__,__,__,__,__,__,__,__,__,W2,__,__,oo },
-    { oo,__,W2,__,__,__,__,__,__,__,__,__,__,__,W2,__,oo },
-    { oo,W3,__,__,__,__,__,__,W3,__,__,__,__,__,__,W3,oo },
-    { oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo,oo }
-};
-
-
 Board::Board(const GameParams &iParams):
-    m_params(iParams),
+    m_params(iParams), m_layout(iParams.getBoardLayout()),
     m_tilesRow(BOARD_REALDIM, Tile()),
     m_tilesCol(BOARD_REALDIM, Tile()),
     m_jokerRow(BOARD_REALDIM, false),
@@ -129,7 +81,7 @@ wstring Board::getDisplayStr(int iRow, int iCol) const
            "Trying to get the display string on an empty board square");
     wstring str = getTile(iRow, iCol).getDisplayStr();
     if (isJoker(iRow, iCol))
-        std::transform(str.begin(), str.end(), str.begin(), towlower);
+        str = toLower(str);
     return str;
 }
 
@@ -142,8 +94,7 @@ bool Board::isJoker(int iRow, int iCol) const
 
 bool Board::isVacant(int iRow, int iCol) const
 {
-    ASSERT(iRow >= BOARD_MIN && iRow <= BOARD_MAX &&
-           iCol >= BOARD_MIN && iCol <= BOARD_MAX, "Invalid coordinates");
+    ASSERT(m_layout.isValidCoord(iRow, iCol), "Invalid coordinates");
     return m_tilesRow[iRow][iCol].isEmpty();
 }
 
@@ -154,7 +105,7 @@ void Board::addRound(const Dictionary &iDic, const Round &iRound)
     int col = iRound.getCoord().getCol();
     if (iRound.getCoord().getDir() == Coord::HORIZONTAL)
     {
-        for (unsigned int i = 0; i < iRound.getWordLen(); i++)
+        for (unsigned i = 0; i < iRound.getWordLen(); i++)
         {
             const Tile &t = iRound.getTile(i);
             if (isVacant(row, col + i))
@@ -270,7 +221,7 @@ int Board::checkRoundAux(const Matrix<Tile> &iTilesMx,
                          const Matrix<Cross> &iCrossMx,
                          const Matrix<int> &iPointsMx,
                          const Matrix<bool> &iJokerMx,
-                         Round &iRound) const
+                         Round &iRound, bool checkJunction) const
 {
     bool isolated = true;
 
@@ -282,12 +233,13 @@ int Board::checkRoundAux(const Matrix<Tile> &iTilesMx,
     int col = iRound.getCoord().getCol();
 
     // Is the word going out of the board?
-    if (col + iRound.getWordLen() > BOARD_MAX + 1)
+    if (col + iRound.getWordLen() >= BOARD_REALDIM)
         return 8;
 
     // Is the word an extension of another word?
-    if (!iTilesMx[row][col - 1].isEmpty() ||
-        !iTilesMx[row][col + iRound.getWordLen()].isEmpty())
+    if (checkJunction &&
+        (!iTilesMx[row][col - 1].isEmpty() ||
+         !iTilesMx[row][col + iRound.getWordLen()].isEmpty()))
     {
         return 1;
     }
@@ -323,16 +275,17 @@ int Board::checkRoundAux(const Matrix<Tile> &iTilesMx,
 
                 int l;
                 if (!iRound.isJoker(i))
-                    l = t.getPoints() * m_tileMultipliers[row][col + i];
+                    l = t.getPoints() * getLayout().getLetterMultiplier(row, col + i);
                 else
                     l = 0;
                 pts += l;
-                wordmul *= m_wordMultipliers[row][col + i];
+                int wm = getLayout().getWordMultiplier(row, col + i);
+                wordmul *= wm;
 
                 int p = iPointsMx[row][col + i];
                 if (p >= 0)
                 {
-                    ptscross += (p + l) * m_wordMultipliers[row][col + i];
+                    ptscross += (p + l) * wm;
                 }
                 ++fromrack;
                 iRound.setFromRack(i);
@@ -340,7 +293,8 @@ int Board::checkRoundAux(const Matrix<Tile> &iTilesMx,
             else
             {
                 // The letter is not in the crosscheck
-                return 3;
+                if (checkJunction)
+                    return 3;
             }
         }
     }
@@ -351,12 +305,12 @@ int Board::checkRoundAux(const Matrix<Tile> &iTilesMx,
 
     // We may not be allowed to use so many letters from the rack
     // (cf. "7 among 8" variant)
-    if (fromrack > m_params.getLettersToPlay())
+    if (checkJunction && fromrack > m_params.getLettersToPlay())
         return 9;
 
     // The word must cover at least one anchor square, except
     // for the first turn
-    if (isolated && !m_isEmpty)
+    if (checkJunction && isolated && !m_isEmpty)
         return 5;
     // The first word must be horizontal
     // Deactivated, as a vertical first word is allowed in free games,
@@ -366,7 +320,7 @@ int Board::checkRoundAux(const Matrix<Tile> &iTilesMx,
         return 6;
 #endif
     // The first word must cover the H8 square
-    if (m_isEmpty
+    if (checkJunction && m_isEmpty
         && (row != 8 || col > 8 || col + iRound.getWordLen() <= 8))
     {
         return 7;
@@ -385,12 +339,12 @@ int Board::checkRoundAux(const Matrix<Tile> &iTilesMx,
 }
 
 
-int Board::checkRound(Round &iRound) const
+int Board::checkRound(Round &iRound, bool checkJunction) const
 {
     if (iRound.getCoord().getDir() == Coord::HORIZONTAL)
     {
         return checkRoundAux(m_tilesRow, m_crossRow,
-                             m_pointRow, m_jokerRow, iRound);
+                             m_pointRow, m_jokerRow, iRound, checkJunction);
     }
     else
     {
@@ -399,7 +353,7 @@ int Board::checkRound(Round &iRound) const
         iRound.accessCoord().swap();
 
         int res = checkRoundAux(m_tilesCol, m_crossCol,
-                                m_pointCol, m_jokerCol, iRound);
+                                m_pointCol, m_jokerCol, iRound, checkJunction);
 
         // Restore the coordinates
         iRound.accessCoord().swap();
@@ -465,24 +419,6 @@ const Tile& Board::getTestTile(int iRow, int iCol) const
 }
 
 
-int Board::GetWordMultiplier(int iRow, int iCol)
-{
-    if (iRow < BOARD_MIN || iRow > BOARD_MAX ||
-        iCol < BOARD_MIN || iCol > BOARD_MAX)
-        return 0;
-    return m_wordMultipliers[iRow][iCol];
-}
-
-
-int Board::GetLetterMultiplier(int iRow, int iCol)
-{
-    if (iRow < BOARD_MIN || iRow > BOARD_MAX ||
-        iCol < BOARD_MIN || iCol > BOARD_MAX)
-        return 0;
-    return m_tileMultipliers[iRow][iCol];
-}
-
-
 // #define CELL_STRING_FORMAT "[%c:%s:%2d]"
 #define CELL_STRING_FORMAT "[%s:%2d]"
 
@@ -510,9 +446,11 @@ string Board::getCellContent_col(int row, int col) const
 #ifdef DEBUG
 void Board::checkDouble()
 {
-    for (int row = BOARD_MIN; row <= BOARD_MAX; row++)
+    const unsigned nbRows = m_layout.getRowCount();
+    const unsigned nbCols = m_layout.getColCount();
+    for (unsigned row = 1; row <= nbRows; row++)
     {
-        for (int col = BOARD_MIN; col <= BOARD_MAX; col++)
+        for (unsigned col = 1; col <= nbCols; col++)
         {
             ASSERT(m_tilesRow[row][col] == m_tilesCol[col][row],
                    "Tiles inconsistency at " << row << "x" << col);
