@@ -49,16 +49,13 @@ public:
     static void Destroy();
 
     /// Create a game
-    Game *createGame(const GameParams &iParams);
+    Game *createGame(const GameParams &iParams, const Game *iMasterGame = NULL);
 
     /// Return the loaded game, or NULL if there was a problem
     Game *load(const string &iFileName, const Dictionary &iDic);
 
     Game *createFromCmdLine(int argc, char **argv);
 
-    /// Destroy a Game object, created by any of the createXXX methods above
-    void releaseGame(Game &iGame);
-
 private:
 
     GameFactory();
