@@ -20,21 +20,21 @@
 
 #include <boost/foreach.hpp>
 
-#include <algorithm>
 #include <wctype.h>
 #include <sstream>
 
 #include "move.h"
 #include "rack.h"
 #include "pldrack.h"
+#include "encoding.h"
 #include "debug.h"
 
 
 INIT_LOGGER(game, Move);
 
 
-Move::Move()
-    :m_score(0)
+Move::Move(int iPoints)
+    :m_score(iPoints)
 {
     m_type = NO_MOVE;
 }
@@ -60,8 +60,7 @@ Move::Move(const wstring &iLetters)
     : m_score(0), m_letters(iLetters)
 {
     // Make the letters uppercase
-    std::transform(m_letters.begin(), m_letters.end(),
-                   m_letters.begin(), towupper);
+    m_letters = toUpper(m_letters);
 
     if (m_letters.empty())
         m_type = PASS;
@@ -164,3 +163,15 @@ wstring Move::toString() const
     return wss.str();
 }
 
+
+bool Move::operator==(const Move &iOther) const
+{
+    return m_type == iOther.m_type
+        && m_score == iOther.m_score
+        && m_word == iOther.m_word
+        && m_coord == iOther.m_coord
+        && m_letters == iOther.m_letters
+        && m_round == iOther.m_round;
+}
+
+
