@@ -21,7 +21,6 @@
 
 #include <string>
 #include <sstream>
-#include <algorithm> // For std::transform
 #include <wctype.h>
 #include "tile.h"
 #include "round.h"
@@ -124,7 +123,7 @@ wstring Round::getWord() const
     {
         wstring chr = getTile(i).getDisplayStr();
         if (isJoker(i))
-            std::transform(chr.begin(), chr.end(), chr.begin(), towlower);
+            chr = toLower(chr);
         s += chr;
     }
     return s;
@@ -154,3 +153,14 @@ wstring Round::toString() const
     return oss.str();
 }
 
+
+bool Round::operator==(const Round &iOther) const
+{
+    return m_word == iOther.m_word
+        && m_rackOrigin == iOther.m_rackOrigin
+        && m_coord == iOther.m_coord
+        && m_points == iOther.m_points
+        && m_bonus == iOther.m_bonus;
+}
+
+
