@@ -20,20 +20,21 @@
 
 #include "config.h"
 
-#include <QtGui/QLabel>
-#include <QtGui/QFrame>
-#include <QtGui/QMessageBox>
-#include <QtGui/QFileDialog>
-#include <QtGui/QDockWidget>
-#include <QtGui/QCloseEvent>
-#include <QtGui/QPrintPreviewDialog>
-#include <QtGui/QPrintDialog>
-#include <QtGui/QPrinter>
-#include <QtGui/QPainter>
-#include <QtGui/QDesktopServices>
-#include <QtGui/QDesktopWidget>
-#include <QtCore/QSettings>
-#include <QtCore/QUrl>
+#include <QGuiApplication>
+#include <QLabel>
+#include <QFrame>
+#include <QMessageBox>
+#include <QFileDialog>
+#include <QDockWidget>
+#include <QCloseEvent>
+#include <QPrintPreviewDialog>
+#include <QPrintDialog>
+#include <QPrinter>
+#include <QPainter>
+#include <QDesktopServices>
+#include <QScreen>
+#include <QSettings>
+#include <QUrl>
 
 #include "main_window.h"
 #include "dic.h"
@@ -656,7 +657,7 @@ void MainWindow::readSettings()
     QSize size = settings.value("size").toSize();
     if (size.isValid())
         resize(size);
-    const QRect &desktopRect = QApplication::desktop()->screenGeometry();
+    const QRect &desktopRect = qGuiApp->primaryScreen()->geometry();
     QPoint point = settings.value("pos", QPoint(20, 20)).toPoint();
     // If the position was saved when an external monitor was plugged, and
     // is restored when the monitor is not there anymore, the window could
@@ -1114,7 +1115,7 @@ void MainWindow::print(QPrinter *printer)
     int curHeight = (LINE_HEIGHT + textHeight + 1) / 2;
     for (unsigned int i = 0; i < nbCols; ++i)
     {
-        int textWidth = fm.width(colTitles[i]);
+        int textWidth = fm.horizontalAdvance(colTitles[i]);
         painter.drawText(curWidth + (colWidths[i] - textWidth) / 2,
                          curHeight,  colTitles[i]);
         curWidth += colWidths[i];
