@@ -20,16 +20,16 @@
 
 #include "config.h"
 
-#include <QtGui/QTableWidget>
-#include <QtGui/QPushButton>
-#include <QtGui/QHeaderView>
-#include <QtGui/QComboBox>
-#include <QtGui/QSpinBox>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QMenu>
-#include <QtGui/QAction>
-#include <QtGui/QShortcut>
-#include <QtCore/QSettings>
+#include <QTableWidget>
+#include <QPushButton>
+#include <QHeaderView>
+#include <QComboBox>
+#include <QSpinBox>
+#include <QKeyEvent>
+#include <QMenu>
+#include <QAction>
+#include <QShortcut>
+#include <QSettings>
 
 #include "players_table_helper.h"
 #include "custom_popup.h"
