@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *****************************************************************************/
 
-#include <QtGui/QLineEdit>
-#include <QtGui/QValidator>
+#include <QLineEdit>
+#include <QValidator>
 
 #include "validator_factory.h"
 #include "qtcommon.h"
