@@ -49,7 +49,7 @@ public:
     static void printBoardMultipliers(ostream &out, const PublicGame &iGame);
 
     static void printNonPlayed(ostream &out, const PublicGame &iGame);
-    static void printPlayedRack(ostream &out, const PublicGame &iGame, int n);
+    static void printPlayedRack(ostream &out, const PublicGame &iGame);
     static void printAllRacks(ostream &out, const PublicGame &iGame);
     static void printSearchResults(ostream &out, const Results &iResults, int);
     static void printPoints(ostream &out, const PublicGame &iGame);
